% Example with a real data set in "Wavelet density estimation for
% stratified size-biased sample"
% by Pepa Ramirez & Brani Vidakovic.

% In this example we consider two stratified samples of size 379 of alcohol
% levels (BAC) of male drivers in fatal driving accidents. BACs of men aged
% under than or more than 30 years old consitute the two different strata.
% The biasing functions are fixed a priori, g(y) = y (BAC > 30) and
% g(y) = sqrt(y) (BAC < 30).


%  The program calls to:
%           1) Phijk.m -- Daubechies-Lagarias Algorithm. 
%           2) dwtr.m and idwtr.m -- forward and inverse wavelet transform.
%           3) loc_lin.m and kernel.m -- local linear smoother with a
%           Gaussian kernel.
%
%--------------------------------------------------------------------------
close all
clear all
lw = 2;  
set(0, 'DefaultAxesFontSize', 16);
fs = 14;
msize = 5;
load RealData
y1=BAC_more30;
y2=BAC_less30;
n1=length(y1);
n2=length(y2);
%--------------------
% Biasing functions: g1(y)=y, g2(y)=y^1/2;
muhat1 = n1./sum(1./y1);
muhat2= n2./sum(1./(y2.^(1/2)));
filter = [-0.07576571478934,  -0.02963552764595,   0.49761866763246,   0.80373875180522,...
   0.29785779560554,  -0.09921954357694,  -0.01260396726226,   0.03222310060407];


J=7;
cs1 =[];
for k = 0:(2^J-1)
    cJk1 = 0;
for i = 1:n1
    cJk1 = cJk1 + Phijk(y1(i), J, k, filter, 20)/y1(i); %Evaluation of the scaling function corresponding to an Orthogonal 
            %MRA by Daubechies-Lagarias Algorithm.
end
cJk1 = muhat1/(n1+n2) * cJk1;
cs1 =[cs1 cJk1];
end
cs1 = 2^(J/2) * cs1;


cs2 =[];
for k = 0:(2^J-1)
    cJk2 = 0;
for i = 1:n2
    cJk2 = cJk2 + Phijk(y2(i), J, k, filter, 20)/(y2(i)^(1/2));
    %cJk2 = cJk2 + Phijk(ym(i), J, k, filter, 20)/(log(ym(i)));
end
cJk2 = muhat2/(n1+n2) * cJk2;
cs2 =[cs2 cJk2];
end
cs2 = 2^(J/2) * cs2;

linear_est = cs1 + cs2; % projection estimate
a = linspace(0,.6, length(linear_est));

% Compute the thresholded estimate.
wf = MakeONFilterExt('Coiflet',1);
csw = dwtr(linear_est, 6, wf); 
nn = length(csw);
nn2 = nn/2;
finest = csw(nn2+1:nn);
sf = sqrt(var(finest));
lambda = sqrt( 2 * log(nn)) * sf;
cswt = csw .* ( abs(csw) > lambda); 
smooth_th = idwtr(cswt, 6, wf); % projection estimate after thresholding.
figure;
plot(a(1:75), linear_est(1:75),'k:'); %the rest of values are 0.
hold on
plot(a(1:75), smooth_th(1:75),'k'); % approximated f^X



